@@ -4,7 +4,6 @@
 #include "spvm_typedecl.h"
 
 enum {
-  SPVM_DESCRIPTOR_C_ID_CALLBACK_T,
   SPVM_DESCRIPTOR_C_ID_MULNUM_T,
   SPVM_DESCRIPTOR_C_ID_POINTER_T,
   SPVM_DESCRIPTOR_C_ID_NATIVE,
@@ -16,6 +15,7 @@ enum {
   SPVM_DESCRIPTOR_C_ID_WO,
   SPVM_DESCRIPTOR_C_ID_STATIC,
   SPVM_DESCRIPTOR_C_ID_INTERFACE_T,
+  SPVM_DESCRIPTOR_C_ID_REQUIRED,
 };
 
 // Field information
