@@ -16,8 +16,8 @@ SPVM_LIST* SPVM_LIST_new_list_permanent(SPVM_ALLOCATOR* allocator, int32_t capac
 void SPVM_LIST_free(SPVM_LIST* array);
 void SPVM_LIST_maybe_extend(SPVM_LIST* array);
 void SPVM_LIST_push(SPVM_LIST* array, void* value);
-void* SPVM_LIST_fetch(SPVM_LIST* array, int32_t index);
-void SPVM_LIST_store(SPVM_LIST* array, int32_t index, void* value);
+void* SPVM_LIST_get(SPVM_LIST* array, int32_t index);
+void SPVM_LIST_set(SPVM_LIST* array, int32_t index, void* value);
 void* SPVM_LIST_pop(SPVM_LIST* array);
 void* SPVM_LIST_shift(SPVM_LIST* array);
 
